==========
Next steps
==========

Your OpenStack environment now includes the dashboard.

After you install and configure the dashboard, you can
complete the following tasks:

* Provide users with a public IP address, a username, and a password
  so they can access the dashboard through a web browser. In case of
  any SSL certificate connection problems, point the server
  IP address to a domain name, and give users access.

* Customize your dashboard. For details, see :doc:`/admin/customize-configure`.

* Set up session storage. For derails, see :doc:`/admin/sessions`.

* To use the VNC client with the dashboard, the browser
  must support HTML5 Canvas and HTML5 WebSockets.

  For details about browsers that support noVNC, see
  `README
  <https://github.com/novnc/noVNC/blob/master/README.md>`__
  and `browser support
  <https://github.com/novnc/noVNC/wiki/Browser-support>`__.
